@@ -11,6 +11,16 @@ from userena import settings as userena_settings
 
 import urllib, random, datetime
 
+try:
+    from django.utils.text import truncate_words
+except ImportError:
+    # Django >=1.5
+    from django.utils.text import Truncator
+    from django.utils.functional import allow_lazy
+    def truncate_words(s, num, end_text='...'):
+        truncate = end_text and ' %s' % end_text or ''
+        return Truncator(s).words(num, truncate=truncate)
+    truncate_words = allow_lazy(truncate_words, unicode)
 
 def get_gravatar(email, size=80, default='identicon'):
     """ Get's a Gravatar for a email address.
@@ -98,9 +108,11 @@ def generate_sha1(string, salt=None):
     """
     if not isinstance(string, (str, unicode)):
         string = str(string)
+    if isinstance(string, unicode):
+        string = string.encode("utf-8")
     if not salt:
         salt = sha_constructor(str(random.random())).hexdigest()[:5]
-    hash = sha_constructor(salt+str(string.encode('utf-8'))).hexdigest()
+    hash = sha_constructor(salt+string).hexdigest()
 
     return (salt, hash)
 
